summaryrefslogtreecommitdiffstats
path: root/sys
diff options
context:
space:
mode:
authorphk <phk@FreeBSD.org>1994-09-27 20:39:54 +0000
committerphk <phk@FreeBSD.org>1994-09-27 20:39:54 +0000
commit5c792336a6f2f7dfe1d230522764b075bba3a7a7 (patch)
tree391542b1f1cf59b38c49e6c480bf8f2693b10d62 /sys
parentf5a12741b57ff792f19c1240e4e8b761f7f3ad21 (diff)
downloadFreeBSD-src-5c792336a6f2f7dfe1d230522764b075bba3a7a7.zip
FreeBSD-src-5c792336a6f2f7dfe1d230522764b075bba3a7a7.tar.gz
ktrace.c: added decl of ktrnamei
lkm.h: added decl of lkmdispatch mount.h: added decl of vfs_busy,vfs_unbusy syscall: The "created from" changed.
Diffstat (limited to 'sys')
-rw-r--r--sys/sys/ktrace.h6
-rw-r--r--sys/sys/lkm.h5
-rw-r--r--sys/sys/mount.h10
-rw-r--r--sys/sys/syscall-hide.h2
-rw-r--r--sys/sys/syscall.h2
5 files changed, 16 insertions, 9 deletions
diff --git a/sys/sys/ktrace.h b/sys/sys/ktrace.h
index f0ced8d..1d1022e 100644
--- a/sys/sys/ktrace.h
+++ b/sys/sys/ktrace.h
@@ -31,7 +31,7 @@
* SUCH DAMAGE.
*
* @(#)ktrace.h 8.1 (Berkeley) 6/2/93
- * $Id: ktrace.h,v 1.2 1994/08/02 07:53:09 davidg Exp $
+ * $Id: ktrace.h,v 1.3 1994/08/21 04:41:49 paul Exp $
*/
#ifndef _SYS_KTRACE_H_
@@ -149,7 +149,9 @@ struct ktr_csw {
#define KTRFAC_INHERIT 0x40000000 /* pass trace flags to children */
#define KTRFAC_ACTIVE 0x20000000 /* ktrace logging in progress, ignore */
-#ifndef KERNEL
+#ifdef KERNEL
+int ktrnamei __P((struct vnode *vp,char *path));
+#else /* KERNEL */
#include <sys/cdefs.h>
diff --git a/sys/sys/lkm.h b/sys/sys/lkm.h
index cd89fd0..7e26e47 100644
--- a/sys/sys/lkm.h
+++ b/sys/sys/lkm.h
@@ -34,7 +34,7 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * $Id: lkm.h,v 1.1 1994/08/20 02:23:40 davidg Exp $
+ * $Id: lkm.h,v 1.2 1994/09/21 03:47:30 wollman Exp $
*/
#ifndef _SYS_LKM_H_
@@ -60,6 +60,7 @@ typedef enum loadmod {
#ifdef KERNEL
+
/*
* Loadable system call
*/
@@ -285,6 +286,8 @@ extern int nosys();
} \
return lkmdispatch(lkmtp, cmd);
+int lkmdispatch __P((struct lkm_table *lkmtp, int cmd));
+
#endif /* KERNEL */
/****************************************************************************/
diff --git a/sys/sys/syscall-hide.h b/sys/sys/syscall-hide.h
index 66912df..b2598bb 100644
--- a/sys/sys/syscall-hide.h
+++ b/sys/sys/syscall-hide.h
@@ -2,7 +2,7 @@
* System call hiders.
*
* DO NOT EDIT-- this file is automatically generated.
- * created from $Id: syscalls.master,v 1.8 1994/09/13 14:46:54 dfr Exp $
+ * created from $Id: syscalls.master,v 1.9 1994/09/18 20:39:50 wollman Exp $
*/
HIDE_POSIX(fork)
diff --git a/sys/sys/syscall.h b/sys/sys/syscall.h
index fd409d2..5d53601 100644
--- a/sys/sys/syscall.h
+++ b/sys/sys/syscall.h
@@ -2,7 +2,7 @@
* System call numbers.
*
* DO NOT EDIT-- this file is automatically generated.
- * created from $Id: syscalls.master,v 1.8 1994/09/13 14:46:54 dfr Exp $
+ * created from $Id: syscalls.master,v 1.9 1994/09/18 20:39:50 wollman Exp $
*/
#define SYS_syscall 0
OpenPOWER on IntegriCloud
diff --git a/sys/sys/mount.h b/sys/sys/mount.h
index fe9f4cb..e7fdd60 100644
--- a/sys/sys/mount.h
+++ b/sys/sys/mount.h
@@ -31,7 +31,7 @@
* SUCH DAMAGE.
*
* @(#)mount.h 8.13 (Berkeley) 3/27/94
- * $Id: mount.h,v 1.8 1994/09/21 03:47:31 wollman Exp $
+ * $Id: mount.h,v 1.10 1994/09/22 01:05:03 wollman Exp $
*/
#ifndef _SYS_MOUNT_H_
@@ -463,9 +463,11 @@ int vfs_export /* process mount export info */
__P((struct mount *, struct netexport *, struct export_args *));
struct netcred *vfs_export_lookup /* lookup host in fs export list */
__P((struct mount *, struct netexport *, struct mbuf *));
-int vfs_lock __P((struct mount *)); /* lock a vfs */
-int vfs_mountedon __P((struct vnode *));/* is a vfs mounted on vp */
-void vfs_unlock __P((struct mount *)); /* unlock a vfs */
+int vfs_lock __P((struct mount *)); /* lock a vfs */
+int vfs_mountedon __P((struct vnode *)); /* is a vfs mounted on vp */
+void vfs_unlock __P((struct mount *)); /* unlock a vfs */
+int vfs_busy __P((struct mount *)); /* mark a vfs busy */
+void vfs_unbusy __P((struct mount *)); /* mark a vfs not busy */
extern TAILQ_HEAD(mntlist, mount) mountlist; /* mounted filesystem list */
extern struct vfsops *vfssw[]; /* filesystem type table */